@@ -4,7 +4,11 @@
 
 deviance.manylm <- function (object, na.action="na.omit", ...) {
 
-wr <- as.matrix(weighted.residuals(object))
+if (is.null(object$weighted.residuals))
+   wr <- as.matrix(object$residuals)
+else
+   wr <- as.matrix(object$weighted.residuals)
+
 
 if (na.action=="na.fail") wr <- na.fail(wr)  else
 if (na.action=="na.omit") wr <- na.omit(wr)  else
