@@ -7,13 +7,14 @@ manyglm <- function (formula, family="negative.binomial", K=1, data=NULL, subset
 
 # start by converting any family objects that can be handled over to character strings 
 if(class(family)=="family"){
-  if(family$family=="binomial" & family$link=="cloglog")
+  fam = family
+  if(fam$family=="binomial" & fam$link=="cloglog")
     family="cloglog"
-  if(family$family=="binomial" & family$link=="logit")
+  if(fam$family=="binomial" & fam$link=="logit")
     family="binomial"
-  if(family$family=="poisson" & family$link=="log")
+  if(fam$family=="poisson" & fam$link=="log")
     family="poisson"
-  if(family$family=="gaussian" & family$link=="identity")
+  if(fam$family=="gaussian" & fam$link=="identity")
     family="gaussian"
 }
   
@@ -48,8 +49,8 @@ if ( is.character(family) ) {
     }   
     else stop (paste("'family'", family, "not recognized"))
 }
-else stop ("Please specify a family function with a character string. manyglm supports the following members of the exponential family: 'gaussian', 'poisson', 'binomial', 'cloglog', 'negative.binomial', distributions.") 
-
+else stop("'family' not recognised. See ?manyglm for currently available options.") 
+  
 #stop ("Current manyglm only supports the following link function for binary binomial regression: 'logit', 'cloglog'.") 
 
 ret.x <- x
@@ -115,7 +116,7 @@ if ( familynum==3 || familynum==4 ) {
 
 # Obtain regression parameters
 if (familyname=="gaussian") { 
-    stop("Please use manylm to fit Guassian")
+    stop("Please use manylm to fit Gaussian")
 #   z <- manylm(formula, data=data, subset=subset, na.action=na.action, model=model, x=x, y =y, qr=qr, cor.type=cor.type, shrink.param=shrink.param, tol=tol, ...)
 #    z$family <- "gaussian"
 #    z$formula <- formula
