@@ -50,11 +50,16 @@ summary.manyglm <- function(object, resamp="pit.trap", test="wald", p.uni="none"
         if (any(w < 0)) stop("negative 'weights' not allowed")
     }
 
-    if (object$family == "poisson") familynum <- 1
-    else if (object$family == "negative.binomial") familynum <- 2
-    else if (object$family == "binomial") familynum <- 3 
-    else stop("'family' not defined. Choose one of 'poisson', 'negative.binomial', 'binomial' for an manyglm object") 
+    # the following values need to be converted to integer types  
 
+
+	  if (object$family == "poisson") { familynum <- 1; linkfun = 0 } 
+	  else if (object$family == "negative.binomial") { familynum <- 2; linkfun = 0 }
+	  else if (object$family == "binomial(link=logit)") { familynum <- 3; linkfun = 0 }
+	  else if (object$family == "binomial(link=cloglog)") { familynum <- 3; linkfun = 1}
+	  else stop("'family' not recognised. See ?manyglm for currently available options.") 
+	
+  
     if(object$theta.method == "ML") methodnum <- 0
     else if (object$theta.method == "Chi2") methodnum <- 1 
     else if (object$theta.method == "PHI") methodnum <- 2 
@@ -152,7 +157,7 @@ summary.manyglm <- function(object, resamp="pit.trap", test="wald", p.uni="none"
     else if (corrnum == 0) shrink.param <- c(rep(1,nParam+2))
     else if (corrnum == 1) shrink.param <- c(rep(0,nParam+2))
     
-    modelParam <- list(tol=tol, regression=familynum, estimation=methodnum, stablizer=0, n=object$K, maxiter=object$maxiter, maxiter2=object$maxiter2, warning=warn)
+    modelParam <- list(tol=tol, regression=familynum, link=linkfun, estimation=methodnum, stablizer=0, n=object$K, maxiter=object$maxiter, maxiter2=object$maxiter2, warning=warn)
     # note that nboot excludes the original dataset
     testParams <- list(tol=tol, nboot=nBoot-1, cor_type=corrnum, test_type=testnum, resamp=resampnum, reprand=rep.seed, punit=pu, showtime=st, warning=warn)
     if(is.null(object$offset)) O <- matrix(0, nrow=nRows, ncol=nVars)
